"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContributorsGenerator = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const fetcher_1 = require("./fetcher");
const processor_1 = require("./processor");
const TEMPLATE_DIR = path_1.default.join(process.cwd(), 'src', 'templates');
class ContributorsGenerator {
    static async generate() {
        try {
            const contributors = await fetcher_1.ContributorFetcher.fetch();
            const processed = processor_1.ContributorProcessor.process(contributors);
            const [header, topContributorsTemplate, allContributorsTemplate, footer] = await Promise.all([
                this.readTemplate('header.md'),
                this.readTemplate('top-contributors.md'),
                this.readTemplate('all-contributors.md'),
                this.readTemplate('footer.md')
            ]);
            const content = this.buildContent(processed, {
                header,
                topContributorsTemplate,
                allContributorsTemplate,
                footer
            });
            await fs_1.promises.writeFile('CONTRIBUTORS.md', content);
            console.log('Successfully generated CONTRIBUTORS.md');
        }
        catch (error) {
            console.error('Error generating contributors:', error instanceof Error ? error.message : String(error));
            process.exit(1);
        }
    }
    static async readTemplate(name) {
        return fs_1.promises.readFile(path_1.default.join(TEMPLATE_DIR, name), 'utf8');
    }
    static buildContent(contributors, templates) {
        const currentDate = new Date().toLocaleDateString('en-US', {
            month: 'long',
            day: 'numeric',
            year: 'numeric'
        });
        const top5 = contributors.slice(0, 5);
        const allContributors = contributors;
        const renderContributor = (c, size, extraStyle = '') => templates.topContributorsTemplate
            .replace('{{AVATAR_URL}}', `${c.avatar_url}?s=${size}&r=g`)
            .replace('{{PROFILE_URL}}', c.html_url)
            .replace('{{USERNAME}}', c.login)
            .replace('{{COMMITS}}', c.contributions.toString())
            .replace('{{WIDTH}}', size.toString())
            .replace('<div align="center"', `<div align="center" style="${extraStyle}"`);
        // Top contributors with more spacing
        const topContributors = top5.map(c => renderContributor(c, 100, 'margin: 20px;')).join('\n');
        // All contributors in a tight grid
        const allContributorsGrid = allContributors
            .map(c => renderContributor(c, 80, 'margin: 5px;'))
            .join('\n');
        return [
            templates.header.trim(),
            `<div style="display: flex; flex-wrap: wrap; justify-content: center; gap: 10px;">${topContributors}</div>`,
            templates.allContributorsTemplate.replace('{{CONTRIBUTORS_GRID}}', allContributorsGrid),
            templates.footer.replace('{{DATE}}', currentDate)
        ].join('\n\n');
    }
}
exports.ContributorsGenerator = ContributorsGenerator;
(async () => {
    console.log('Generating CONTRIBUTORS.md...');
    await ContributorsGenerator.generate();
})();
